@@ -202,7 +202,7 @@ NpmPublishTask.prototype = new (function () {
           jake.exec(cmds, function () {
             console.log('Published to NPM');
             complete();
-          }, {stdout: true});
+          }, {printStdout: true, printStderr: true});
         }, 5000);
       });
 
