@@ -44,8 +44,12 @@ var path = require('path')
   });
 
  */
-var TestTask = function (name, definition) {
-  var self = this;
+var TestTask = function () {
+  var self = this
+    , args = Array.prototype.slice.call(arguments)
+    , name = args.shift()
+    , definition = args.pop()
+    , prereqs = args.pop() || [];
 
   /**
     @name jake.TestTask#testNam
@@ -79,7 +83,15 @@ var TestTask = function (name, definition) {
   if (this.showDescription) {
     desc('Run the tests for ' + name);
   }
-  task(this.testName, [self.testName + ':run'], function () {});
+
+  task(this.testName, prereqs, {async: true}, function () {
+    var t = jake.Task[self.testName + ':run'];
+    t.on('complete', function () {
+      complete();
+    });
+    // Pass args to the namespaced test
+    t.invoke.apply(t, arguments);
+  });
 
   namespace(self.testName, function () {
 
